@@ -30,8 +30,7 @@ def _restore():
     curses.nl()
 
 
-def run_userinit():
-    fname = os.path.join(kaa.app.config.KAADIR, '__kaa__.py')
+def run_userinit(fname):
     if os.path.isfile(fname):
         with open(fname) as f:
             src = f.read()
@@ -44,7 +43,7 @@ def run_userinit():
 
 
 def main(stdscr):
-    conf = config.Config()
+    conf = config.Config(opt)
     sys.path.insert(0, conf.KAADIR)
 
     kaa.log.init(conf.LOGDIR)
@@ -55,12 +54,16 @@ def main(stdscr):
 
         kaa.app = app.CuiApp(conf)
         kaa.app.storage = fileio.FileStorage()
+        
+        if not opt.no_init:
+            fname = opt.init_script
+            if not fname:
+                fname = os.path.join(kaa.app.config.KAADIR, '__kaa__.py')
+            run_userinit(fname)
 
         mainframe = frame.MainFrame(stdscr)
         kaa.app.init(mainframe)
 
-        run_userinit()
-
         if not opt.file:
             # no file args. show new document.
             doc = fileio.newfile(provisional=True)
@@ -104,6 +107,9 @@ COLOR_ENVS = ('COLORTERM', 'XTERM_VERSION', 'ROXTERM_ID',
              'KONSOLE_DBUS_SESSION')
 
 def _init_term():
+    if opt.term:
+        os.environ['TERM'] = opt.term
+
     # http://fedoraproject.org/wiki/Features/256_Color_Terminals
     for env in COLOR_ENVS:
         if os.environ.get(env):
@@ -114,6 +120,7 @@ def _init_term():
         
     if has_color:
         term = os.environ.get('TERM')
+            
         if term in ('xterm', 'screen', 'Eterm'):
             term = term+'-256color'
             os.environ['TERM'] = term
