@@ -213,8 +213,16 @@ class DefaultMode(modebase.ModeBase):
             if d.get(key) == 0:
                 return pos
 
-    HeaderInfo = namedtuple(
-                    'header_info', ['token', 'parents', 'name', 'dispname', 
-                                    'lineno', 'pos'])
+    _headerinfo = namedtuple('_headerinfo', 
+            ['token', 'parent', 'name', 'dispname', 'lineno', 'pos'])
+    class HeaderInfo(_headerinfo):
+        def get_parents(self):
+            ret = []
+            p = self.parent
+            while p:
+                ret.insert(0, p)
+                p = p.parent
+            return ret
+
     def get_headers(self):
         return ()
