@@ -3,7 +3,7 @@ from kaa.highlight import Tokenizer, Span
 from kaa.theme import Theme, Style
 
 DiffThemes = {
-    'default':
+    'basic':
         Theme([
             Style('default', 'Base00', None),
             Style('fromfile', 'Orange', None),
@@ -12,7 +12,7 @@ DiffThemes = {
             Style('remove', 'Orange', None, bold=True),
             Style('add', 'Yellow', None, bold=True),
             Style('header', 'Orange', None),
-        ])
+        ]),
 }
 
 def build_tokenizer():
