@@ -49,76 +49,76 @@ class FileInfoMode(dialogmode.DialogMode):
         mode = self.target.document.mode
         fileinfo = self.target.document.fileinfo
 
-        f = dialogmode.FormBuilder(self.document)
-        f.append_text('caption', '    File name: ')
-        f.append_text('default', ' {}\n'.format(fname.replace('&', '&&')))
-
-        f.append_text('caption', '    Directory: ')
-        f.append_text('default', ' {}\n'.format(dir.replace('&', '&&')))
-
-        f.append_text('default', '\n')
-
-        f.append_text('caption', '         Mode: ')
-        f.append_text('default', ' {}     '.format(mode.MODENAME))
-        f.append_text('button', '[Change &Mode]\n',
-                      on_shortcut=self._on_update_mode,
-                      shortcut_style='shortcut',
-                      shortcut_need_alt=False)
-
-        f.append_text('caption', '     Encoding: ')
-        f.append_text('default', ' {}\n'.format(
-            fileinfo.encoding if fileinfo else ''))
-
-        f.append_text('caption', '      Newline: ')
-        f.append_text('default', ' {}\n'.format(
-            fileinfo.newline if fileinfo else ''))
-
-        f.append_text('caption', '  Line number: ')
-        f.append_text('default', ' {}       '.format(
-            'Show' if mode.SHOW_LINENO else 'Hide'))
-        f.append_text('button', '[Change &Line number]\n',
-                      on_shortcut=self._on_update_lineno,
-                      shortcut_style='shortcut',
-                      shortcut_need_alt=False)
-
-
-        f.append_text('default', '\n')
-
-        f.append_text('caption', '    Tab width: ',
-                      shortcut_style='shortcut')
-        f.append_text('default', ' {}          '.format(mode.tab_width))
-        f.append_text('button', '[Change &Tab width]\n',
-                      on_shortcut=self._on_update_tab,
-                      shortcut_style='shortcut',
-                      shortcut_need_alt=False)
-
-        f.append_text('caption', ' Indent width: ',
-                      shortcut_style='shortcut')
-        f.append_text('default', ' {}          '.format(mode.indent_width))
-        f.append_text('button', '[Change &Indent width]\n',
-                      on_shortcut=self._on_update_indent,
-                      shortcut_style='shortcut',
-                      shortcut_need_alt=False)
-
-
-        f.append_text('caption', '      Use tab: ',
-                      shortcut_style='shortcut')
-        f.append_text('default', ' {}        {}'.format(
-            'Yes' if mode.indent_tab else 'No', '' if mode.indent_tab else ' '))
-        f.append_text('button', '[Change &Use tab]\n',
-                      on_shortcut=self._on_update_usetab,
-                      shortcut_style='shortcut',
-                      shortcut_need_alt=False)
-
-
-        f.append_text('caption', '  Auto Indent: ',
-                      shortcut_style='shortcut')
-        f.append_text('default', ' {}        {}'.format(
-            'Yes' if mode.auto_indent else 'No', '' if mode.auto_indent else ' '))
-        f.append_text('button', '[&Auto Indent]\n',
-                      on_shortcut=self._on_update_autoindent,
-                      shortcut_style='shortcut',
-                      shortcut_need_alt=False)
+        with dialogmode.FormBuilder(self.document) as f:
+            f.append_text('caption', '    File name: ')
+            f.append_text('default', ' {}\n'.format(fname.replace('&', '&&')))
+    
+            f.append_text('caption', '    Directory: ')
+            f.append_text('default', ' {}\n'.format(dir.replace('&', '&&')))
+    
+            f.append_text('default', '\n')
+    
+            f.append_text('caption', '         Mode: ')
+            f.append_text('default', ' {}     '.format(mode.MODENAME))
+            f.append_text('button', '[Change &Mode]\n',
+                          on_shortcut=self._on_update_mode,
+                          shortcut_style='shortcut',
+                          shortcut_need_alt=False)
+    
+            f.append_text('caption', '     Encoding: ')
+            f.append_text('default', ' {}\n'.format(
+                fileinfo.encoding if fileinfo else ''))
+    
+            f.append_text('caption', '      Newline: ')
+            f.append_text('default', ' {}\n'.format(
+                fileinfo.newline if fileinfo else ''))
+    
+            f.append_text('caption', '  Line number: ')
+            f.append_text('default', ' {}       '.format(
+                'Show' if mode.SHOW_LINENO else 'Hide'))
+            f.append_text('button', '[Change &Line number]\n',
+                          on_shortcut=self._on_update_lineno,
+                          shortcut_style='shortcut',
+                          shortcut_need_alt=False)
+    
+    
+            f.append_text('default', '\n')
+    
+            f.append_text('caption', '    Tab width: ',
+                          shortcut_style='shortcut')
+            f.append_text('default', ' {}          '.format(mode.tab_width))
+            f.append_text('button', '[Change &Tab width]\n',
+                          on_shortcut=self._on_update_tab,
+                          shortcut_style='shortcut',
+                          shortcut_need_alt=False)
+    
+            f.append_text('caption', ' Indent width: ',
+                          shortcut_style='shortcut')
+            f.append_text('default', ' {}          '.format(mode.indent_width))
+            f.append_text('button', '[Change &Indent width]\n',
+                          on_shortcut=self._on_update_indent,
+                          shortcut_style='shortcut',
+                          shortcut_need_alt=False)
+    
+    
+            f.append_text('caption', '      Use tab: ',
+                          shortcut_style='shortcut')
+            f.append_text('default', ' {}        {}'.format(
+                'Yes' if mode.indent_tab else 'No', '' if mode.indent_tab else ' '))
+            f.append_text('button', '[Change &Use tab]\n',
+                          on_shortcut=self._on_update_usetab,
+                          shortcut_style='shortcut',
+                          shortcut_need_alt=False)
+    
+    
+            f.append_text('caption', '  Auto Indent: ',
+                          shortcut_style='shortcut')
+            f.append_text('default', ' {}        {}'.format(
+                'Yes' if mode.auto_indent else 'No', '' if mode.auto_indent else ' '))
+            f.append_text('button', '[&Auto Indent]\n',
+                          on_shortcut=self._on_update_autoindent,
+                          shortcut_style='shortcut',
+                          shortcut_need_alt=False)
 
 
     def is_cursor_visible(self):
