@@ -34,13 +34,13 @@ class StatusInfo:
 
 
 StatusBarThemes = {
-    'default':
+    'basic':
         Theme([
             Style('default', 'Red', 'Base02'),
-            Style('filename', 'Menu1', 'Base02'),
+            Style('filename', 'LightBlue', 'Base02'),
             Style('msg', 'Red', 'Base02'),
             Style('editmode', 'Green', 'Base02', rjust=True),
-        ])
+        ]),
 }
 
 class StatusBarMode(modebase.ModeBase):
