@@ -8,7 +8,7 @@ class TestMenuMode(kaa_testutils._TestDocBase):
 
     @patch('kaa.app', create=True)
     def test_msbbox(self, mock):
-        kaa.app.DEFAULT_THEME = 'default'
+        kaa.app.DEFAULT_THEME = 'basic'
 
         target = kaa_testutils._TestScreenBase()._getwnd('')
         doc = menumode.MenuMode.show_menu(target, 'MAIN')
