@@ -8,7 +8,7 @@ class TestSearchDlgMode(kaa_testutils._TestDocBase):
 
     @patch('kaa.app', create=True)
     def test_msbbox(self, mock):
-        kaa.app.DEFAULT_THEME = 'default'
+        kaa.app.DEFAULT_THEME = 'basic'
 
         def cb(c):
             pass
