@@ -9,16 +9,16 @@ class TestPythonMode(kaa_testutils._TestDocBase):
         script = '''
 class spam:
     def ham(self, \, x=(def xxx)):
-        'def\\''
+        'def'
 # class xyz
 def egg():
-   """\\""""
+   """\\\\"""
 def bacon():
 '''
         doc = self._getdoc(script)
         tokens = [t for t in doc.mode.get_headers()]
         assert tokens == [
-            ('namespace', (), 'spam', 'spam', None, 1), 
-            ('function', (tokens[0],), 'spam.ham', 'ham()', None, 13),
-            ('function', (), 'egg', 'egg()', None, 76), 
-            ('function', (), 'bacon', 'bacon()', None, 99)] 
+            ('namespace', None, 'spam', 'spam', None, 1), 
+            ('function', tokens[0], 'spam.ham', 'ham()', None, 13),
+            ('function', None, 'egg', 'egg()', None, 74), 
+            ('function', None, 'bacon', 'bacon()', None, 97)] 
